@@ -82,6 +82,7 @@ class _HTTPManager:
         )
 
         # Add referral ID to header.
+        self.referral_id = referral_id
         if referral_id:
             self.client.headers.update({"Referer": referral_id})
 
@@ -169,6 +170,10 @@ class _HTTPManager:
         if query is None:
             query = {}
 
+        # Add agentSource (spot API's Referer).
+        if self.referral_id and method == "POST" and path.endswith("/spot/v1/order"):
+            query["agentSource"] = self.referral_id
+
         # Remove internal spot arg
         query.pop("spot", "")
 
@@ -290,6 +295,20 @@ class _HTTPManager:
                 else:
                     raise e
 
+            # Check HTTP status code before trying to decode JSON.
+            if s.status_code != 200:
+                if s.status_code == 403:
+                    error_msg = "You have breached the IP rate limit."
+                else:
+                    error_msg = "HTTP status code is not 200."
+                self.logger.debug(f"Response text: {s.text}")
+                raise FailedRequestError(
+                    request=f"{method} {path}: {req_params}",
+                    message=error_msg,
+                    status_code=s.status_code,
+                    time=dt.utcnow().strftime("%H:%M:%S")
+                )
+
             # Convert response to dictionary, or raise if requests error.
             try:
                 s_json = s.json()
@@ -301,6 +320,7 @@ class _HTTPManager:
                     time.sleep(self.retry_delay)
                     continue
                 else:
+                    self.logger.debug(f"Response text: {s.text}")
                     raise FailedRequestError(
                         request=f"{method} {path}: {req_params}",
                         message="Conflict. Could not decode JSON.",
@@ -846,4 +866,3 @@ class _USDCHTTPManager(_HTTPManager):
             query=kwargs,
             auth=True
         )
-
