@@ -27,7 +27,7 @@ SPOT = "Spot"
 class _WebSocketManager:
     def __init__(self, callback_function, ws_name,
                  test, domain="", api_key=None, api_secret=None,
-                 ping_interval=30, ping_timeout=10,
+                 ping_interval=20, ping_timeout=10, retries=10,
                  restart_on_error=True, trace_logging=False):
 
         self.test = test
@@ -48,9 +48,14 @@ class _WebSocketManager:
         #   }
         self.callback_directory = {}
 
+        # Record the subscriptions made so that we can resubscribe if the WSS
+        # connection is broken.
+        self.subscriptions = []
+
         # Set ping settings.
         self.ping_interval = ping_interval
         self.ping_timeout = ping_timeout
+        self.retries = retries
 
         # Other optional data handling settings.
         self.handle_error = restart_on_error
@@ -61,6 +66,7 @@ class _WebSocketManager:
 
         # Set initial state, initialize dictionary and connect.
         self._reset()
+        self.attempting_connection = False
 
     def _on_open(self):
         """
@@ -74,11 +80,38 @@ class _WebSocketManager:
         """
         self.callback(json.loads(message))
 
+    def is_connected(self):
+        try:
+            if self.ws.sock or not self.ws.sock.is_connected:
+                return True
+            else:
+                return False
+        except AttributeError:
+            return False
+
+    @staticmethod
+    def _are_connections_connected(active_connections):
+        for connection in active_connections:
+            if not connection.is_connected():
+                return False
+        return True
+
     def _connect(self, url):
         """
         Open websocket in a thread.
         """
 
+        def resubscribe_to_topics():
+            if not self.subscriptions:
+                # There are no subscriptions to resubscribe to, probably
+                # because this is a brand new WSS initialisation so there was
+                # no previous WSS connection.
+                return
+            for subscription_message in self.subscriptions:
+                self.ws.send(subscription_message)
+
+        self.attempting_connection = True
+
         # Set endpoint.
         subdomain = SUBDOMAIN_TESTNET if self.test else SUBDOMAIN_MAINNET
         domain = DOMAIN_MAIN if not self.domain else self.domain
@@ -89,39 +122,53 @@ class _WebSocketManager:
         self.public_v2_websocket = True if url.endswith("v2") else False
         self.private_websocket = True if url.endswith("/spot/ws") else False
 
-        self.ws = websocket.WebSocketApp(
-            url=url,
-            on_message=lambda ws, msg: self._on_message(msg),
-            on_close=self._on_close(),
-            on_open=self._on_open(),
-            on_error=lambda ws, err: self._on_error(err)
-        )
-
-        # Setup the thread running WebSocketApp.
-        self.wst = threading.Thread(target=lambda: self.ws.run_forever(
-            ping_interval=self.ping_interval,
-            ping_timeout=self.ping_timeout
-        ))
-
-        # Configure as daemon; start.
-        self.wst.daemon = True
-        self.wst.start()
-
         # Attempt to connect for X seconds.
-        retries = 10
-        while retries > 0 and (not self.ws.sock or not self.ws.sock.connected):
+        retries = self.retries
+        if retries == 0:
+            infinitely_reconnect = True
+        else:
+            infinitely_reconnect = False
+        while (infinitely_reconnect or retries > 0) and not self.is_connected():
+            logger.info(f"WebSocket {self.ws_name} attempting connection...")
+            self.ws = websocket.WebSocketApp(
+                url=url,
+                on_message=lambda ws, msg: self._on_message(msg),
+                on_close=self._on_close(),
+                on_open=self._on_open(),
+                on_error=lambda ws, err: self._on_error(err)
+            )
+
+            # Setup the thread running WebSocketApp.
+            self.wst = threading.Thread(target=lambda: self.ws.run_forever(
+                ping_interval=self.ping_interval,
+                ping_timeout=self.ping_timeout
+            ))
+
+            # Configure as daemon; start.
+            self.wst.daemon = True
+            self.wst.start()
+
             retries -= 1
             time.sleep(1)
 
-        # If connection was not successful, raise error.
-        if retries <= 0:
-            self.exit()
-            raise websocket.WebSocketTimeoutException("Connection failed.")
+            # If connection was not successful, raise error.
+            if not infinitely_reconnect and retries <= 0:
+                self.exit()
+                raise websocket.WebSocketTimeoutException(
+                    f"WebSocket {self.ws_name} connection failed. Too many "
+                    f"connection attempts. pybit will "
+                    f"no longer try to reconnect.")
+
+        logger.info(f"WebSocket {self.ws_name} connected")
 
         # If given an api_key, authenticate.
         if self.api_key and self.api_secret:
             self._auth()
 
+        resubscribe_to_topics()
+
+        self.attempting_connection = False
+
     def _auth(self):
         """
         Authorize websocket connection.
@@ -155,7 +202,7 @@ class _WebSocketManager:
             self.exit()
 
         # Reconnect.
-        if self.handle_error:
+        if self.handle_error and not self.attempting_connection:
             self._reset()
             self._connect(self.endpoint)
 
@@ -233,12 +280,16 @@ class _FuturesWebSocketManager(_WebSocketManager):
         subscription_args = prepare_subscription_args(symbol)
         self._check_callback_directory(subscription_args)
 
-        self.ws.send(
-            json.dumps({
+        while not self.is_connected():
+            # Wait until the connection is open before subscribing.
+            time.sleep(0.1)
+
+        subscription_message = json.dumps({
                 "op": "subscribe",
                 "args": subscription_args
             })
-        )
+        self.ws.send(subscription_message)
+        self.subscriptions.append(subscription_message)
         self._set_callback(topic, callback)
 
     def _initialise_local_data(self, topic):
